@@ -269,7 +269,7 @@ pub enum ValType {
     F32,
     F64,
     String,
-    Anyref,
+    Externref,
     I32,
     I64,
 }
@@ -288,7 +288,7 @@ impl<'a> Parse<'a> for ValType {
             8 => ValType::F32,
             9 => ValType::F64,
             10 => ValType::String,
-            11 => ValType::Anyref,
+            11 => ValType::Externref,
             12 => ValType::I32,
             13 => ValType::I64,
             n => return Err(parser.error(ErrorKind::InvalidValType(n))),
